Runcrate
========

.. image:: https://github.com/ResearchObject/runcrate/workflows/ci/badge.svg?branch=main
   :target: https://github.com/ResearchObject/runcrate/actions?workflow=ci
   :alt: CI

.. image:: https://codecov.io/gh/ResearchObject/runcrate/branch/main/graph/badge.svg
   :target: https://codecov.io/gh/ResearchObject/runcrate
   :alt: Codecov

.. image:: https://zenodo.org/badge/DOI/10.5281/zenodo.7762627.svg
   :target: https://doi.org/10.5281/zenodo.7762627
   :alt: Zenodo

Runcrate is a software toolkit to manipulate `Workflow Run RO-Crate <https://www.researchobject.org/workflow-run-crate/>`_ packages.

Documentation is at http://www.researchobject.org/runcrate/.
